#include "alist.h"
#include "loadfile.h"
#include "config.h"
#include "cdbslib.h"
#include "mkload.h"

//------------------------------------------------------------------------
// Name: read_obsmode
//
// Description: Read observation mode from a table into a list.
//              Non-observation mode columns are skipped over during 
//              the list formation, along with any expload-wildcard values. 
//
//------------------------------------------------------------------------
void read_obsmode (table *tab,      // i: open table descriptor
                   alist *obsmode   // o: observation mode list
                   )
{
    int		icol;
    char	*obscol, *obsval;

    // these columns are skipped when forming observation mode list
    static char	*nonobsmode = "change_level|pedigree|\
observation_begin_date|observation_end_date|expansion_number|comment";

    // EXPLOAD wildcard values are skipped when forming observation mode list
    static char *wildcards = WILDCARD_LIST;

    // NB: Changes to mkloadbody must be coordinated with this function.
    //
    // put all values from obsmode columns (columns NOT in nonobsmode set above)
    // into the obsmode list, EXCEPT those that have expload wildcard values
    //
    for (icol = 0; icol < ncol_table (tab); icol ++) {
	obscol = get_tab_colname (tab, icol);

	if (!strmatch (obscol, nonobsmode)) {
	    obsval = get_tab_cell_bynum (tab, icol, 0);
	    if (!strmatch (obsval, wildcards))
		add_alist (obsmode, obscol, obsval);
	}
    }
}
